==> jc-1.4.0.tar.gz: polyglot/lex/Literal.h <==
// public abstract class polyglot.lex.Literal

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_Literal_H_
#define _JC_polyglot_lex_Literal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Literal$sub_refs	_jc_polyglot_lex_Literal$sub_refs;
typedef struct _jc_polyglot_lex_Literal$sub_nonrefs	_jc_polyglot_lex_Literal$sub_nonrefs;
typedef struct _jc_polyglot_lex_Literal$refs	_jc_polyglot_lex_Literal$refs;
typedef struct _jc_polyglot_lex_Literal$nonrefs	_jc_polyglot_lex_Literal$nonrefs;
typedef struct _jc_polyglot_lex_Literal$object	_jc_polyglot_lex_Literal$object;

typedef const struct _jc_polyglot_lex_Literal$vmethods	_jc_polyglot_lex_Literal$vmethods;
typedef const struct _jc_polyglot_lex_Literal$vtable	_jc_polyglot_lex_Literal$vtable;
typedef const struct _jc_polyglot_lex_Literal$vtype	_jc_polyglot_lex_Literal$vtype;

// Constructors
extern void _jc_polyglot_lex_Literal$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_Literal$object *, struct _jc_polyglot_util_Position$object *, jint);

// Virtual methods structure
struct _jc_polyglot_lex_Literal$vmethods {
};

// Vtable
struct _jc_polyglot_lex_Literal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
};

// Vtype
struct _jc_polyglot_lex_Literal$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Literal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Literal$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Literal$refs {
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Literal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Literal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
};

// Object instance structure
struct _jc_polyglot_lex_Literal$object {
	_jc_polyglot_lex_Literal$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Literal$vtype	*vtype;
	_jc_polyglot_lex_Literal$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Literal$vtype _jc_polyglot_lex_Literal$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Literal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Literal$class_object;

#endif	/* _JC_polyglot_lex_Literal_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/Literal.h <==
// public abstract class polyglot.lex.Literal

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_lex_Literal_H_
#define _JC_polyglot_lex_Literal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Literal$sub_refs	_jc_polyglot_lex_Literal$sub_refs;
typedef struct _jc_polyglot_lex_Literal$sub_nonrefs	_jc_polyglot_lex_Literal$sub_nonrefs;
typedef struct _jc_polyglot_lex_Literal$refs	_jc_polyglot_lex_Literal$refs;
typedef struct _jc_polyglot_lex_Literal$nonrefs	_jc_polyglot_lex_Literal$nonrefs;
typedef struct _jc_polyglot_lex_Literal$object	_jc_polyglot_lex_Literal$object;

typedef const struct _jc_polyglot_lex_Literal$vmethods	_jc_polyglot_lex_Literal$vmethods;
typedef const struct _jc_polyglot_lex_Literal$vtable	_jc_polyglot_lex_Literal$vtable;
typedef const struct _jc_polyglot_lex_Literal$vtype	_jc_polyglot_lex_Literal$vtype;

// Constructors
extern void _jc_polyglot_lex_Literal$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_Literal$object *, struct _jc_polyglot_util_Position$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_lex_Literal$vmethods {
};

// Vtable
struct _jc_polyglot_lex_Literal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
};

// Vtype
struct _jc_polyglot_lex_Literal$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Literal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Literal$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Literal$refs {
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Literal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Literal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
};

// Object instance structure
struct _jc_polyglot_lex_Literal$object {
	_jc_polyglot_lex_Literal$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Literal$vtype	*vtype;
	_jc_polyglot_lex_Literal$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Literal$vtype _jc_polyglot_lex_Literal$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Literal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Literal$class_object;

#endif	/* _JC_polyglot_lex_Literal_H_ */
